==> f3dasm-0.2.95.tar.gz: f3dasm-0.2.95/README.md <==
<center>
	<img src="./docs/img/f3dasm-logo.svg" alt="F3DASM logo" />
</center>

***

[![Python](https://img.shields.io/badge/python-3.7-blue)](https://www.python.org)
[![pypi](https://img.shields.io/pypi/v/f3dasm.svg)](https://pypi.org/project/f3dasm/)
[![GitHub license](https://img.shields.io/badge/license-BSD-blue)](https://github.com/optuna/optuna)

[**Docs**](https://bessagroup.github.io/F3DASM/)
| [**Installation**](https://bessagroup.github.io/F3DASM/gettingstarted.html)
| [**GitHub**](https://github.com/bessagroup/F3DASM/tree/versionmartin)
| [**PyPI**](https://pypi.org/project/f3dasm/)
| [**Practical sessions**](https://github.com/mpvanderschelling/F3DASM_practical)

This code intends to facilitate the design and analysis of materials & structures/metamaterials

The Bessa research group at TU Delft is small... At the moment, we have limited availability to help future users/developers adapting the code to new problems, but we will do our best to help!

* Created by M.A. Bessa (M.A.Bessa@tudelft.nl) in September 2016
* Current developer: [M.P. van der Schelling](https://github.com/mpvanderschelling/) (M.P.vanderSchelling@tudelft.nl)

## Referencing

If you use or edit our work, please cite at least one of the appropriate references:

[1] Bessa, M. A., Bostanabad, R., Liu, Z., Hu, A., Apley, D. W., Brinson, C., Chen, W., & Liu, W. K. (2017). A framework for data-driven analysis of materials under uncertainty: Countering the curse of dimensionality. Computer Methods in Applied Mechanics and Engineering, 320, 633-667.

[2] Bessa, M. A., & Pellegrino, S. (2018). Design of ultra-thin shell structures in the stochastic post-buckling range using Bayesian machine learning and optimization. International Journal of Solids and Structures, 139, 174-188.

[3] Bessa, M. A., Glowacki, P., & Houlder, M. (2019). Bayesian machine learning in metamaterial design: fragile becomes super-compressible. Advanced Materials, 31(48), 1904845.

[4] Mojtaba, M., Bostanabad, R., Chen, W., Ehmann, K., Cao, J., & Bessa, M. A. (2019). Deep learning predicts path-dependent plasticity. Proceedings of the National Academy of Sciences, 116(52), 26414-26420.

==> f3dasm-0.9.3.tar.gz: f3dasm-0.9.3/README.md <==
f3dasm
------
*Framework for data-driven design \& analysis of structures and materials*

***

[![Python](https://img.shields.io/pypi/pyversions/f3dasm)](https://www.python.org)
[![pypi](https://img.shields.io/pypi/v/f3dasm.svg)](https://pypi.org/project/f3dasm/)
[![GitHub license](https://img.shields.io/badge/license-BSD-blue)](https://github.com/bessagroup/f3dasm)

[**Docs**](https://bessagroup.github.io/F3DASM/)
| [**Installation**](https://bessagroup.github.io/F3DASM/gettingstarted.html)
| [**GitHub**](https://github.com/bessagroup/F3DASM/tree/versionmartin)
| [**PyPI**](https://pypi.org/project/f3dasm/)
| [**Practical sessions**](https://github.com/mpvanderschelling/F3DASM_practical)

Welcome to `f3dasm`, a Python package for data-driven design and analysis of structures and materials.

* Created by M.A. Bessa (M.A.Bessa@tudelft.nl) in September 2016
* Current developer and maintainer: [M.P. van der Schelling](https://github.com/mpvanderschelling/) (M.P.vanderSchelling@tudelft.nl)

The Bessa research group at TU Delft is small... At the moment, we have limited availability to help future users/developers adapting the code to new problems, but we will do our best to help!

## Referencing

If you use or edit our work, please cite at least one of the appropriate references:

[1] Bessa, M. A., Bostanabad, R., Liu, Z., Hu, A., Apley, D. W., Brinson, C., Chen, W., & Liu, W. K. (2017). A framework for data-driven analysis of materials under uncertainty: Countering the curse of dimensionality. Computer Methods in Applied Mechanics and Engineering, 320, 633-667.

[2] Bessa, M. A., & Pellegrino, S. (2018). Design of ultra-thin shell structures in the stochastic post-buckling range using Bayesian machine learning and optimization. International Journal of Solids and Structures, 139, 174-188.

[3] Bessa, M. A., Glowacki, P., & Houlder, M. (2019). Bayesian machine learning in metamaterial design: fragile becomes super-compressible. Advanced Materials, 31(48), 1904845.

[4] Mojtaba, M., Bostanabad, R., Chen, W., Ehmann, K., Cao, J., & Bessa, M. A. (2019). Deep learning predicts path-dependent plasticity. Proceedings of the National Academy of Sciences, 116(52), 26414-26420.
